@@ -28,7 +28,8 @@
 #' 
 #' Methods/functions beginning with \code{.} are not exported
 #' 
-#' @return character vector of variables names
+#' @return character vector of variables names in order that they appear in
+#' \code{x}.
 #' 
 #' @seealso 
 #'   \code{\link[base]{all.vars}}
@@ -110,11 +111,23 @@ setMethod( 'get.vars', c( 'name', 'ANY' ) ,
 
 
 
-# # ---------------------------------------------------------------------
-# #' @rdname get.vars
-# #' @aliases get.vars,ANY,ANY-methods
-# setMethod( 'get.vars', c( 'ANY', 'ANY' ), 
-#   function( x, data, ... ) NULL
-# )
+# ---------------------------------------------------------------------
+#' @rdname get.vars
+#' @aliases get.vars,ANY,ANY-methods
+setMethod( 'get.vars', c( 'ANY', 'ANY' ), 
+  function( x, data, ... ) character(0)
+)
+
+
+
+
+
+# ---------------------------------------------------------------------
+#' @rdname get.vars
+#' @aliases get.vars,NULL,ANY-methods
+setMethod( 'get.vars', c( 'NULL', 'ANY' ), 
+  function( x, data, ... ) NULL 
+)
+
 
 
